@@ -17,9 +17,9 @@ CalibrationSet Class
 
 """
 from itertools import product
-from .calibration import Calibration
-from ..networkSet import NetworkSet
 
+from ..networkSet import NetworkSet
+from .calibration import Calibration
 
 
 def cartesian_product(ideals, measured_sets, *args, **kwargs):
@@ -27,7 +27,7 @@ def cartesian_product(ideals, measured_sets, *args, **kwargs):
     """
     measured_lists = product(*[k[:] for k in measured_sets])
     return [Calibration(ideals = ideals, measured = measured,
-        *args, **kwargs) for measured in measured_lists ]
+        **kwargs) for measured in measured_lists ]
 
 def dot_product(ideals, measured_sets, *args, **kwargs):
     """
@@ -41,7 +41,7 @@ def dot_product(ideals, measured_sets, *args, **kwargs):
         measured = [measured_set[k] for measured_set in measured_sets]
         cal_list.append(
             Calibration(ideals=ideals, measured= measured,
-            *args,**kwargs)
+            **kwargs)
             )
 
     return cal_list
@@ -55,7 +55,9 @@ class CalibrationSet:
     References
     -----------
 
-    .. [1] A. Arsenovic, L. Chen, M. F. Bauwens, H. Li, N. S. Barker, and R. M. Weikle, "An Experimental Technique for Calibration Uncertainty Analysis," IEEE Transactions on Microwave Theory and Techniques, vol. 61, no. 1, pp. 263-269, 2013.
+    .. [1] A. Arsenovic, L. Chen, M. F. Bauwens, H. Li, N. S. Barker, and R. M. Weikle,
+    "An Experimental Technique for Calibration Uncertainty Analysis,"
+    IEEE Transactions on Microwave Theory and Techniques, vol. 61, no. 1, pp. 263-269, 2013.
 
     """
 
@@ -136,5 +138,5 @@ class Dot(CalibrationSet):
         for k in range(len(measured_sets[0])):
             measured = [measured_set[k] for measured_set in measured_sets]
             cal = self.cal_class(ideals=ideals, measured= measured,
-                                 *args,**kwargs)
+                                 **kwargs)
             self.cal_list.append(cal)
