@@ -317,6 +317,7 @@ class Mdif:
         params = dict()
 
         in_data_block = False
+        in_noise_block = False
 
         for line in fid:
 
@@ -343,19 +344,31 @@ class Mdif:
             # ....
             # end
             if line.lower().startswith('end'):
-                ntwk = self._parse_data(block_data)
-                ntwk.params = params
-                ntwks.append(ntwk)
+                if in_data_block:
+                    ntwk = self._parse_data(block_data)
+                    ntwk.params = params
+                    ntwks.append(ntwk)
+                    # reset parsed values
+                    in_data_block = False
+                    params = dict()
+                if in_noise_block:
+                    in_noise_block = False
+                    noise_arr = np.array(
+                        [e.split() for e in block_data if not e.startswith(("!", "#", "%"))]
+                        ).astype(float)
+                    freq, nfmin, gamma_opt_mag, gamma_opt_angle, rn = noise_arr.T
+                    nfreq = Frequency.from_f(freq, unit=ntwk.frequency.unit)
+                    gamma = gamma_opt_mag * np.exp(1j*np.deg2rad(gamma_opt_angle))
+                    ntwk.set_noise_a(nfreq, nfmin, gamma, rn * ntwk.z0[0,0])
 
-                # reset parsed values
-                in_data_block = False
                 block_data = []
-                params = dict()
 
-            if in_data_block:
+            if in_data_block or in_noise_block:
                 block_data.append(line)
 
-            if line.lower().startswith('begin'):
+            if line.lower().startswith("begin ndata"):
+                in_noise_block = True
+            elif line.lower().startswith('begin'):
                 in_data_block = True
 
         return ntwks
@@ -453,6 +466,7 @@ class Mdif:
                 mdif.write(f"! {c}\n")
 
             nports = ns[0].nports
+            is_noisy = ns[0].noisy
 
             optionstring = Mdif.__create_optionstring(nports)
 
@@ -475,8 +489,17 @@ class Mdif:
                 mdif.write("\nBEGIN ACDATA\n")
                 mdif.write(optionstring + "\n")
                 mdif.write("! network name: " + ntwk.name + "\n")
-                data = ntwk.write_touchstone(return_string=True, **kwargs)
+
+                data = ntwk.write_touchstone(return_string=True, write_noise=False, **kwargs)
                 mdif.write(data)
+
+                if is_noisy:
+                    # this "END" terminates "ACDATA" (s-parameters) and begins noise ("NDATA")
+                    mdif.write("END\n\nBEGIN NDATA\n")
+                    mdif.write("%F nfmin n11x n11y rn\n")
+                    mdif.write(f"# {ntwk.frequency.unit} S MA R {ntwk.z0[0, 0].real}\n")
+                    ntwk._write_noisedata(output=mdif)
+
                 mdif.write("END\n\n")
 
     def __eq__(self, other) -> bool:
