@@ -1,7 +1,7 @@
 import os
 import unittest
 
-import numpy as npy
+import numpy as np
 import pytest
 from numpy.testing import assert_almost_equal, assert_array_almost_equal
 
@@ -52,7 +52,7 @@ class MediaTestCase(unittest.TestCase):
         """
         # create a dummy Coaxial media for various attenuation and test the
         # resulting alpha values (real part of gamma)
-        rng = npy.random.default_rng()
+        rng = np.random.default_rng()
         frequency = rf.Frequency(rng.random(), unit='GHz', npoints=1)
         _att = rng.random()
         # dB/m
@@ -75,9 +75,9 @@ class MediaTestCase(unittest.TestCase):
         assert_almost_equal(coax.gamma.real,  _att*rf.meter_2_feet())
 
         with self.assertRaises(ValueError):
-            coax = Coaxial.from_attenuation_VF(frequency=frequency, VF=1, att=npy.array([.1, .2]), unit='Np/feet')
+            coax = Coaxial.from_attenuation_VF(frequency=frequency, VF=1, att=np.array([.1, .2]), unit='Np/feet')
         frequency = rf.Frequency(1., 1.1, unit='GHz', npoints=2)
-        coax = Coaxial.from_attenuation_VF(frequency=frequency, VF=1, att=npy.array([.1, .2]), unit='Np/feet')
+        coax = Coaxial.from_attenuation_VF(frequency=frequency, VF=1, att=np.array([.1, .2]), unit='Np/feet')
         self.assertEqual( coax.frequency.f.shape, (2,))
 
 
@@ -92,7 +92,7 @@ class MediaTestCase(unittest.TestCase):
         # k0k1k2 attenuation model
         # values taken for HUBER+SUHNER DATA SHEET Coaxial Cable S_10172_B-1
         # attenuation in dB/m for frequency in GHz
-        att = 0 + 0.0826*npy.sqrt(frequency.f_scaled) + 0.0129*frequency.f_scaled
+        att = 0 + 0.0826*np.sqrt(frequency.f_scaled) + 0.0129*frequency.f_scaled
 
         coax = Coaxial.from_attenuation_VF(frequency=frequency, att=att, unit='dB/m')
         # check alpha in gamma
@@ -112,12 +112,12 @@ class MediaTestCase(unittest.TestCase):
         coax = Coaxial(freq, z0_port = 50, Dint = dint, Dout = 1.0e-3,
                        sigma = 1/rho)
 
-        dc_res = rho / (npy.pi * (dint/2)**2)
+        dc_res = rho / (np.pi * (dint/2)**2)
 
         # Old R calculation valid only when skin depth is much smaller
         # then inner conductor radius
         with pytest.warns(RuntimeWarning, match="divide by zero"):
-            R_simple = coax.Rs/(2*npy.pi)*(1/coax.a + 1/coax.b)
+            R_simple = coax.Rs/(2*np.pi)*(1/coax.a + 1/coax.b)
 
             self.assertTrue(abs(1 - coax.R[0]/dc_res) < 1e-2)
             self.assertTrue(abs(1 - coax.R[1]/R_simple[1]) < 1e-2)
